# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################
import os

import wx
import wx.xrc
import wx.dataview

import AI.Analiz
import AI.OpnSrc as OS
from AI.Analiz import *
from AI.Generats import *


from Config.Init import *
import Res.Allicons as icon

import Database.MenuSet2 as MS
import Database.PostGet as PG
import GUI.proman as pro
import importlib
#import importlib.util

_ = wx.GetTranslation
###########################################################################
## Class MyPanel3
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__( self, parent,For_This_Frame=[], id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 544,450 ), style = wx.TAB_TRAVERSAL, name = u'Program Develop' ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.FTF = For_This_Frame

		self.getMData = MS.GetData(u'Menu2.db', u'')
		self.setMDate = MS.SetData(u'', u'', u'')
		# Parameter Init
		self.iSrc_api_Imp = self.getMData.GetImpCod('7777')[0][0]


		self.Splt1 = wx.SplitterWindow( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.SP_3D|wx.SP_LIVE_UPDATE|wx.SP_NO_XP_THEME|wx.SP_THIN_SASH )
		#self.Splt1.SetSashGravity( -1 )
		self.Splt1.Bind( wx.EVT_IDLE, self.Splt1OnIdle )

		self.P1 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz2 = wx.BoxSizer( wx.VERTICAL )

		self.lbl1 = wx.StaticText( self.P1, wx.ID_ANY, _(u"List of Programs:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl1.Wrap( -1 )

		Vsz2.Add( self.lbl1, 0, wx.ALL|wx.EXPAND, 5 )

		self.DVC1 = wx.dataview.TreeListCtrl( self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )

		self.Col1 = self.DVC1.AppendColumn( _(u"Program name"),  200, wx.ALIGN_LEFT, wx.dataview.DATAVIEW_COL_RESIZABLE )
		self.Col2 = self.DVC1.AppendColumn( _(u"ID"),  25, wx.ALIGN_LEFT, wx.dataview.DATAVIEW_COL_RESIZABLE )
		Vsz2.Add( self.DVC1, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn1.SetBitmap( wx.Bitmap( ICON16_PATH + u'application_add.png', wx.BITMAP_TYPE_ANY ) )
		self.btn1.SetBitmap(icon.application_add.GetBitmap())
		self.btn1.SetToolTip( _(u"Add") )

		Hsz1.Add( self.btn1, 0, wx.ALL, 5 )

		self.btn2 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn2.SetBitmap( wx.Bitmap( ICON16_PATH + u'application_edit.png', wx.BITMAP_TYPE_ANY ) )
		self.btn2.SetBitmap(icon.application_edit.GetBitmap())
		self.btn2.SetToolTip(_(u"Edit"))
		Hsz1.Add( self.btn2, 0, wx.ALL, 5 )

		self.btn3 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn3.SetBitmap( wx.Bitmap( ICON16_PATH + u'application_delete.png', wx.BITMAP_TYPE_ANY ) )
		self.btn3.SetBitmap(icon.application_delete.GetBitmap())
		self.btn3.SetToolTip(_(u"Delete"))
		Hsz1.Add( self.btn3, 0, wx.ALL, 5 )

		self.btn4 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn4.SetBitmap( wx.Bitmap( ICON16_PATH + u'application_form.png', wx.BITMAP_TYPE_ANY ))
		self.btn4.SetBitmap(icon.application_form.GetBitmap())
		self.btn4.SetToolTip(_(u"Preview"))
		Hsz1.Add( self.btn4, 0, wx.ALL, 5 )

		self.btn5 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn5.SetBitmap( wx.Bitmap( ICON16_PATH + u'update.png', wx.BITMAP_TYPE_ANY ) )
		self.btn5.SetBitmap(icon.update.GetBitmap())
		self.btn5.SetToolTip(_(u"Update"))
		Hsz1.Add( self.btn5, 0, wx.ALL, 5 )

		self.btn6 = wx.BitmapButton( self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize, wx.BU_AUTODRAW|0 )

		#self.btn6.SetBitmap( wx.Bitmap( ICON16_PATH + u'accept_button.png', wx.BITMAP_TYPE_ANY ) )
		self.btn6.SetBitmap(icon.accept_button.GetBitmap())
		self.btn6.SetToolTip(_(u"Apply"))
		Hsz1.Add( self.btn6, 0, wx.ALL, 5 )


		self.btn7 = wx.BitmapButton(self.P1, wx.ID_ANY, wx.NullBitmap, wx.DefaultPosition, wx.DefaultSize,wx.BU_AUTODRAW | 0)

		#self.btn7.SetBitmap(wx.Bitmap(ICON16_PATH + u'application_lightning.png', wx.BITMAP_TYPE_ANY))
		self.btn7.SetBitmap(icon.application_lightning.GetBitmap())
		self.btn7.SetToolTip(_(u"Generate"))
		Hsz1.Add(self.btn7, 0, wx.ALL, 5)


		Vsz2.Add( Hsz1, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.P1.SetSizer( Vsz2 )
		self.P1.Layout()
		Vsz2.Fit( self.P1 )
		self.P2 = wx.Panel( self.Splt1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz3 = wx.BoxSizer( wx.VERTICAL )

		self.titr = wx.StaticText( self.P2, wx.ID_ANY, _(u"Description:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.titr.Wrap( -1 )

		Vsz3.Add( self.titr, 0, wx.ALL|wx.EXPAND, 5 )

		self.Desc = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, wx.TE_MULTILINE )
		Vsz3.Add( self.Desc, 1, wx.ALL|wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self.P2, wx.ID_ANY, _(u"ID No."), wx.DefaultPosition, wx.Size( 58,-1 ), 0 )
		self.lbl2.Wrap( -1 )

		Hsz2.Add( self.lbl2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld1 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 50,-1 ), 0 )
		Hsz2.Add( self.fld1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lbl3 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Prog. No."), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz2.Add( self.lbl3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld2 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.Size( 50,-1 ), 0 )
		Hsz2.Add( self.fld2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz2, 0, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl4 = wx.StaticText( self.P2, wx.ID_ANY, _(u"import "), wx.DefaultPosition, wx.Size( 58,-1 ), 0 )
		self.lbl4.Wrap( -1 )

		Hsz3.Add( self.lbl4, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld3 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.fld3, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.codgnr = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz3.Add( self.codgnr, 0, wx.ALIGN_CENTER_VERTICAL|wx.TOP|wx.BOTTOM|wx.RIGHT, 5 )


		Vsz3.Add( Hsz3, 0, wx.EXPAND, 5 )

		Hsz5 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl6 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Directory"), wx.DefaultPosition, wx.Size( 58,-1 ), 0 )
		self.lbl6.Wrap( -1 )

		Hsz5.Add( self.lbl6, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.PrgDir1 = wx.DirPickerCtrl( self.P2, wx.ID_ANY, wx.EmptyString, _(u"Select a folder"), wx.DefaultPosition, wx.DefaultSize, wx.DIRP_DEFAULT_STYLE|wx.DIRP_SMALL )
		Hsz5.Add( self.PrgDir1, 1, wx.ALL, 5 )


		Vsz3.Add( Hsz5, 0, wx.EXPAND, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl5 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Parameters"), wx.DefaultPosition, wx.Size( 58,-1 ), 0 )
		self.lbl5.Wrap( -1 )

		Hsz4.Add( self.lbl5, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld4 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.fld4, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz4, 0, wx.EXPAND, 5 )

		Hsz6 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl7 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Link:"), wx.DefaultPosition, wx.Size( 58,-1 ), 0 )
		self.lbl7.Wrap( -1 )

		Hsz6.Add( self.lbl7, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld6 = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz6.Add( self.fld6, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.chk1 = wx.CheckBox( self.P2, wx.ID_ANY, _(u"Public it"), wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz6.Add( self.chk1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz6, 0, wx.EXPAND, 5 )

		self.lin1 = wx.StaticLine( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_HORIZONTAL )
		Vsz3.Add( self.lin1, 0, wx.EXPAND |wx.ALL, 5 )

		Hsz10 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl8 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Database:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl8.Wrap( -1 )

		Hsz10.Add( self.lbl8, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.probtn = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		self.probtn.SetToolTip( _(u"Select Database Tabels and Fields for this program") )

		Hsz10.Add( self.probtn, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz10, 0, wx.EXPAND, 5 )

		Vsz4 = wx.BoxSizer( wx.VERTICAL )

		self.prgfld = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Vsz4.Add( self.prgfld, 0, wx.ALL|wx.EXPAND, 5 )

		self.lbl9 = wx.StaticText( self.P2, wx.ID_ANY, _(u"Directory:"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl9.Wrap( -1 )

		Vsz4.Add( self.lbl9, 0, wx.ALL, 5 )


		Vsz3.Add( Vsz4, 1, wx.EXPAND, 5 )


		self.P2.SetSizer( Vsz3 )
		self.P2.Layout()
		Vsz3.Fit( self.P2 )
		self.Splt1.SplitVertically( self.P1, self.P2, 255 )
		Vsz1.Add( self.Splt1, 1, wx.EXPAND, 5 )

		self.filllist()

		self.fromhere()


		self.SetSizer( Vsz1 )
		self.Layout()


		# Connect Events
		self.DVC1.Bind( wx.dataview.EVT_DATAVIEW_ITEM_ACTIVATED, self.slctmnu, id = wx.ID_ANY )
		self.DVC1.Bind(wx.dataview.EVT_DATAVIEW_SELECTION_CHANGED, self.slctitm, id=wx.ID_ANY)
		self.DVC1.Bind( wx.dataview.EVT_DATAVIEW_ITEM_CONTEXT_MENU, self.conxmnu, id = wx.ID_ANY )
		self.DVC1.Bind( wx.dataview.EVT_DATAVIEW_ITEM_EDITING_DONE, self.endedit, id = wx.ID_ANY )
		self.btn1.Bind( wx.EVT_BUTTON, self.addit )
		self.btn2.Bind( wx.EVT_BUTTON, self.edtit )
		self.btn3.Bind( wx.EVT_BUTTON, self.delit )
		self.btn4.Bind( wx.EVT_BUTTON, self.prviw )
		self.btn5.Bind( wx.EVT_BUTTON, self.updat )
		self.btn6.Bind( wx.EVT_BUTTON, self.aplly )
		self.btn7.Bind( wx.EVT_BUTTON, self.gnrat )
		self.codgnr.Bind( wx.EVT_BUTTON, self.gencod )
		self.PrgDir1.Bind( wx.EVT_DIRPICKER_CHANGED, self.slctdir )
		self.chk1.Bind( wx.EVT_CHECKBOX, self.public )
		self.probtn.Bind( wx.EVT_BUTTON, self.dblst )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def fromhere(self):
		if len(self.FTF) > 0:
			frmname = self.FTF[0].GetTitle()
			#print(frmname)
			self.lbl1.SetLabel(_("List of Programs:")+"    %s" %frmname)

	def filllist(self):
		#self.DVC1.AppendTextColumn()
		# self.my_data = self.getMData.AllHndl("""left join Guidir on Guidir.prgdir = handler.prgdir
		#                                      left join PrgDesc on PrgDesc.handlerid = handler.handlerid
		#                                      where handler.handlerid < 99000
		#                                      and handler.prgdir <> '8888' order by handler.handlerid """)
		self.my_data = self.getMData.AllHndl("""left join Guidir on Guidir.prgdir = handler.prgdir 
				                                     where handler.handlerid < 99000 
				                                     and handler.prgdir <> '8888' order by handler.handlerid """)
		#print(self.my_data)
		allprgnm = [n[1] for n in self.my_data ]
		Aroot = self.DVC1.GetRootItem()
		self.root0 = self.DVC1.AppendItem(Aroot, "All program in Src\API Path")      #code 10-999 dir 2222
		self.root1 = self.DVC1.AppendItem(Aroot, "One page program All-in-One")   #code 1100-1999 dir PRG 1101+
		self.root2 = self.DVC1.AppendItem(Aroot, "One page program for aui panes")  #code 5000-5999 dir 5555
		self.root3 = self.DVC1.AppendItem(Aroot, "Program with one import panel ")  #code 1000-1999 dir 1101+
		#self.root4 = self.DVC1.AppendItem(Aroot, "Multi program with some import ")  #code 2000+ with 2+ import dir 1101+
		self.root5 = self.DVC1.AppendItem(Aroot, "Other python file NOT in Handler ")    #Not in allprgnm

		#alldir = self.getMData.AllGuiDir(
		#	"  where rtrim(Guidir.prgdir,4) > '0000' and ltrim(Guidir.prgdir,4) < '8888' and Guidir.prgdir != '3333' ")
		alldir = self.getMData.AllGuiDir(
			"  where rtrim(Guidir.prgdir,4) > '0000' and ltrim(Guidir.prgdir,4) < '3333' or \
			Guidir.prgdir = '5555' or Guidir.prgdir = '7777' ")
		#lstdir = [d[2] for d in alldir]
		subimp = []
		inlstimport = []
		self.lsthddfil = []
		#print(inlsthndlr)
		for pro in self.my_data:
			if os.path.isfile(MAP + pro[8][2:] + SLASH + pro[1] + '.py'):
				thsfil = MAP + pro[8][2:] + SLASH + pro[1] + '.py'
				af = Anlzfil(thsfil)
				if pro[2] == '5555':
					child = self.DVC1.AppendItem(self.root2, pro[1])
				elif pro[2] == '7777':
					continue
				#elif pro[2] == '2222':
				#	child = self.DVC1.AppendItem(self.root1, pro[1])
				elif pro[2] < '1999':
					if pro[5] >= 1000:
						child = self.DVC1.AppendItem(self.root3, pro[1])
					if pro[5] < 199:
						child = self.DVC1.AppendItem(self.root1, pro[1])

					# if pro[0] > 10000:
					# 	child = self.DVC1.AppendItem(self.root3, pro[1])
					# if pro[0] < 999:
					# 	child = self.DVC1.AppendItem(self.root1, pro[1])

				elif pro[2] not in [prgd[1] for prgd in alldir]:

					child = self.DVC1.AppendItem(self.root1, pro[1])
				else:
					print('Please send your menu2.db file to us')
				self.DVC1.SetItemText(child, 0, pro[1])
				self.DVC1.SetItemText(child, 1, str(pro[0]))

				if af.ishasimport(self.iSrc_api_Imp):
					atimp = af.ishasimport(self.iSrc_api_Imp)[0].split(' ')[1].replace(self.iSrc_api_Imp + '.', '')
					subimp.append(atimp)
					child2 = self.DVC1.AppendItem(child, atimp)
					self.DVC1.SetItemText(child2, 0, atimp)
					self.DVC1.SetItemText(child2, 1, '7777')
					inlstimport.append(atimp+'.py')
				if af.ishasfromim(' . '):
					atimp = af.ishasfromim(' . ')[0].split(' ')[3]
					subimp.append(atimp)
					child3 = self.DVC1.AppendItem(child, atimp)
					self.DVC1.SetItemText(child3, 0, atimp)
					self.DVC1.SetItemText(child3, 1, '7777')
					inlstimport.append(atimp+'.py')

		for diimp ,dircod, hdddir in alldir:
			#print(diimp, dircod, hdddir)
			idr = hdddir.replace('..', MAP)
			if dircod == '2222':
				for ifil in os.listdir(idr):
					#print(ifil)
					if '.py' in ifil:
						if ifil.replace('.py','') not in allprgnm and ifil != '__init__.py':
							child2 = self.DVC1.AppendItem(self.root0, ifil)
							self.DVC1.SetItemText(child2, 0, ifil.replace('.py',''))
							self.DVC1.SetItemText(child2, 1, '2222')
			else:
				for ifil in os.listdir(idr):
					if '.py' in ifil and ifil not in inlstimport:
						if ifil.replace('.py','') not in allprgnm and ifil != '__init__.py' and ifil != 'PAui.py' :
							child2 = self.DVC1.AppendItem(self.root5, ifil)
							self.DVC1.SetItemText(child2, 0, ifil)
							self.DVC1.SetItemText(child2, 1, dircod[:2]+'??')
							self.lsthddfil.append(idr + '\\' + ifil)

		if len(self.FTF) > 0:
			fitm = self.DVC1.GetFirstItem()
			#print(fitm,self.FTF[1],self.FTF[2])
			iitm = self.findthis(self.FTF[1],self.FTF[2],fitm)
			slct = self.DVC1.Select(iitm)
			self.slctitm(slct)

	def findthis(self, mytxt,mycod,fitm):
		if self.DVC1.GetItemText(fitm,0) == mytxt and self.DVC1.GetItemText(fitm,1) == str(mycod):
			return fitm
		else:
			fitm = self.DVC1.GetNextItem(fitm)
			return self.findthis(mytxt,mycod,fitm)

	def slctmnu( self, event ):
		#print(self.DVC1.GetSelection())
		#self.DVC1.SetFocus()
		#self.DVC1.Select(1)
		#print(self.DVC1.GetRootItem())
		event.Skip()

	def slctitm( self, event ):
		self.nullfield()
		txt = ''
		cod = ''
		itm = self.DVC1.GetSelection()
		#print('selct',self.DVC1.GetItemText(itm))
		if itm:
			txt = self.DVC1.GetItemText(itm,0)
			cod = self.DVC1.GetItemText(itm,1)
		#print(txt,cod)
		if cod != '':
			if cod[2:] == '??':
				for l in self.lsthddfil:
					if txt in l.split('\\'):
						self.PrgDir1.SetPath(l)
						self.thsfile = l
						self.thspath = l.replace(txt,'')
						if len(self.getMData.AllGuiDir(" where Guidir.hdddir = '%s' "%self.thspath.replace(MAP,'..').rstrip(SLASH) ))>0:
							self.thsdcod = self.getMData.AllGuiDir(" where Guidir.hdddir = '%s' "%self.thspath.replace(MAP,'..').rstrip(SLASH) )[0][1]
						else:
							self.thsdcod = '1000'

			elif cod != '7777':
				for item in self.my_data:
					if item[1] == txt and item[0] == int(cod) :
						#print(item)
					    self.fillfield(item,item[2])
				if cod == '2222':
					self.thsfile = Src_api+txt+'.py'
					data = (cod, txt, '', '-1', '-1', '-', 'Src.API', '', '..\\Src\\API')
					self.fillfield(data, '')
					self.PrgDir1.SetPath(Src_api)

			# elif cod[0] == '7':
			# 	self.thsfile = GUI_PATH+"API"+SLASH+txt+'.py'
			# 	data = (cod,txt,'','-1','-1','-','GUI.API','','',None,None)
			# 	self.fillfield(data,'')
			# 	self.PrgDir1.SetPath(GUI_PATH+"API"+SLASH)
			elif cod == '7777':
				self.thsfile = Src_gui+txt+'.py' #SRC_PATH+"api"+SLASH+txt+'.py'
				data = (cod,txt,'','-1','-1','-','Src.GUI','','..\\Src\\GUI',None,None)
				self.fillfield(data,'')
				self.PrgDir1.SetPath(Src_gui)   #(SRC_PATH+"api"+SLASH)
		else:
			if 'Src\API' in txt:
				self.Desc.SetValue(u"Here a list of files that exist in Src\API Path that you can use in application ")
			elif 'All-in-One' in txt:
				self.Desc.SetValue(u"Here a list of program that only in one file and when you do it all command execute")
			elif 'aui' in txt:
				self.Desc.SetValue(u"Here a list of files that contains a panel class that you like to select for AuiPane Develop")
			elif 'one import' in txt:
				self.Desc.SetValue(u"Here a List of files that contains a import module in Src\GUI directory and it open that file ")
			#elif 'some import' in txt:
			#	self.Desc.SetValue(u"Here a List of files with some imports that contain several file and command part")
			elif 'NOT' in txt:
				self.Desc.SetValue(u"Here a List of files in your GUI path and Utility that NOT listed in handlers data ")
			else:
				self.Desc.SetValue("")


	def nullfield(self):
		data = ('','','','','','','','','',None,None)
		cods = ''
		self.fillfield(data,cods)

	def fillfield(self, data, cods):
		#print(data)
		self.fld1.SetValue(str(data[0]))
		self.fld2.SetValue(str(data[5]))
		self.dbfuse = ''
		#AI.Analiz.GetImport
		if data[8] != '':
			#print(MAP+data[8][2:]+SLASH+data[1]+'.py')
			myimp = AI.Analiz.Anlzfil(MAP+data[8][2:]+SLASH+data[1]+'.py')
			myimp.parsefil()
			# ii = myimp.getGUIfil()
			# iim = myimp.ishasimport()
			# iim2 = myimp.ishasfromim()
			# print(ii,iim,iim2)
			ii3 = myimp.isDBimexist()
			#print(ii3)
			if ii3:
				dbtxt1,dbtxt2 = myimp.isFiledbexist()
				#print(dbtxt1,dbtxt2)
				if dbtxt1:
					dbf = myimp.findDBintxt(dbtxt1[0])
				if dbtxt2:
					dbf = myimp.findDBintxt(dbtxt2[0])
			else:
				dbf = ''
			self.dbfuse = dbf
			self.prgfld.SetValue(self.dbfuse)

			self.thsfile = MAP+data[8][2:]+SLASH+data[1]+'.py'
			self.thspath = MAP+data[8][2:]
		    #print(self.thsfile,self.thspath)
			self.PrgDir1.SetPath(self.thspath)
		self.fld3.SetValue(Src_gui + '')
		self.fld4.SetValue(str(data[3]))
		self.fld6.SetValue(str(data[4]))


		if data[8] != '':
			#print(myimp.hasDesc())
			if myimp.hasDesc():
				self.Desc.SetValue(myimp.hasDesc())
			else:
				self.Desc.SetValue('')
		else:
			self.Desc.SetValue('')


	def conxmnu( self, event ):
		event.Skip()

	def endedit( self, event ):
		event.Skip()

	def addit( self, event ):
		self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		#self.Pnl = PyPanel(self.Frm, GUI_PATH + 'Temp\\untitle.py')
		self.Pnl = OS.SrcPanel(self.Frm,GUI_PATH + 'Temp\\untitle.py' )
		self.Frm.SetMenuBar(OS.MyMenuBar1(u'Pro'))
		self.Frm.SetSize((700, 560))
		self.Frm.SetLabel('untitle.py')
		self.Frm.Show()
		event.Skip()

	def edtit( self, event ):
		self.Frm = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
		#self.Pnl = PyPanel(self.Frm, self.thsfile)
		self.Pnl = OS.SrcPanel(self.Frm, self.thsfile)
		self.Frm.SetMenuBar(OS.MyMenuBar1(u'Pro'))
		self.Frm.SetSize((700, 560))
		self.Frm.SetLabel(self.thsfile)
		self.Frm.Show()
		event.Skip()

	def delit( self, event ):
		if self.fld1.GetValue() == '':
			answer = wx.MessageBox(_("Do you like delete program [%s] from HDD"%self.thsfile),style=wx.YES_NO)
			#print(answer)
			if answer == 2:
				hndlid = 0
				#print(self.thsfile)
				if os.path.isfile(self.thsfile):
					os.remove(self.thsfile)
					wx.MessageBox(_("File Successfully Remove from HardDisk"))
				else:
					wx.MessageBox(_("File Open or dose not exist please close it or check Harddisk"))

		else:
			hndlid = self.fld1.GetValue()
			# print(hndlid)
			if len(self.getMData.AllHndl(u' where handler.handlerid = %d' % int(hndlid))) > 0:
			    self.setMDate.Table = u'handler'
			    self.setMDate.Delitem(u' handler.handlerid = %d' % int(hndlid))
			if len(self.getMData.AllHndl(u' Join PrgDesc on handler.handlerid = PrgDesc.handlerid \
		                                             where handler.handlerid = %d' % int(hndlid))) > 0:
				self.setMDate.Table = u'PrgDesc'
				self.setMDate.Delitem(u' PrgDesc.handlerid = %d' % int(hndlid))
				wx.MessageBox(_(u"Program successful delete from your list"))
		self.updat(None)
		#event.Skip()

	def prviw( self, event ):
		cdfld = self.fld2.GetValue()
		if len(cdfld) > 0 and cdfld != '-':
			if cdfld[0] == '5' and len(cdfld) == 3:
				a2 = pro.DoProgram2(0, int(self.fld1.GetValue()))
				#print(a2)
				self.Frm = wx.Frame(self, -1, style=wx.FRAME_FLOAT_ON_PARENT|wx.DEFAULT_FRAME_STYLE)
				self.pnl = a2.MyPanel1(self.Frm, id=wx.ID_ANY, pos=wx.DefaultPosition, size=wx.DefaultSize,
				                      style=wx.TAB_TRAVERSAL)
				self.Frm.Show()
			else:
				a2 = pro.DoProgram2(0, int(self.fld1.GetValue()))
				# print(a2)
				win1 = wx.Frame(self, -1)
				a2.main(win1)

		elif cdfld == '' or cdfld == '-':
			if self.fld1.GetValue() == '':
				pass
			af = Anlzfil(self.thsfile)
			ifil = self.thsfile.replace(MAP + '\\', '')
			ifil = ifil.replace('\\', '.')
			ifil = ifil.replace('.py', '')
			m = importlib.import_module(ifil)
			if af.ishasframe():
				try:
					fr = af.ishasframe()
					myclass = getattr(m,fr)
					iframe = myclass(self)
					iframe.Show()
				except AttributeError as e:
					print('not work',e)
			elif af.ishaspanel():
				try:
					pl = af.ishaspanel()
					myclass = getattr(m, pl)
					b = wx.Frame(self, style=wx.CAPTION | wx.CLOSE_BOX | wx.FRAME_FLOAT_ON_PARENT | wx.TAB_TRAVERSAL)
					ipnl = myclass(b)
					b.Show()
				except AttributeError as e:
					print('not work', e)

		event.Skip()

	def updat( self, event ):
		self.DVC1.DeleteAllItems()
		self.filllist()
		self.Refresh()
		#event.Skip()

	def aplly( self, event ):
		itm = self.DVC1.GetSelection()
		txt = self.DVC1.GetItemText(itm, 0)
		cod = self.DVC1.GetItemText(itm, 1)
		if cod[2:] == '??':
			wx.MessageBox(_(u'Please first Generate program then select the correct one to use it'))
		#print(self.FTF)
		else:
			pnl = self.FTF[0].panel
			pnl.prgfld.SetValue(txt)
			pnl.lbl9.SetLabel(_(u"Directory: ")+self.thspath)
			#print(pnl)
			q = self.GetParent()
			q.Close()
		#print(wx.GetTopLevelWindows())
		#event.Skip()

	def gnrat( self, event ):
		itm = self.DVC1.GetSelection()
		txt = self.DVC1.GetItemText(itm, 0)
		cod = self.DVC1.GetItemText(itm, 1)
		af = Anlzfil(self.thsfile)

		#print(txt,cod,self.thsdcod,self.thsfile,self.thspath)
		if cod[2:] == '??':
			def Add2List():
				# print(self.thsdcod)
				lstcod = self.getMData.getHndid(self.thsdcod)
				# print(lstcod)
				# newcod = (int(self.thsdcod[0]) * 10000) + (int(self.thsdcod[1]) * 1000) + len(lstcod) #+ 1
				newcod = int(self.thsdcod[0]) * 10 + len(lstcod)  + 1
				newnom = int(self.thsdcod[0]) * 10 + len(lstcod)  + 1
				data = [newcod, txt.replace('.py', ''), self.thsdcod, '-1', -1, newnom]
				self.setMDate.Table = 'handler'
				self.setMDate.Additem(" handlerid, prgname, prgdir, paramtr, public, prgno", data)
				#CheckDes(newcod)
				wx.MessageBox(_("Program Successfull add to list"))
				self.DVC1.DeleteAllItems()
				self.filllist()
				self.Refresh()

			# def CheckDes(icod):
			# 	if af.hasDesc():
			# 		Desc = af.hasDesc()
			# 		#print(Desc.replace('#', '').replace('Description', '').replace('End', ''))
			# 		data = [icod, Desc.replace('#', '').replace('Description', '').replace('End', '')]
			# 		self.setMDate.Table = 'PrgDesc'
			# 		self.setMDate.Additem(" handlerid, Description ", data)

			a,b,c,d = af.checkSyntx2()
			#print(a,b,c,d)
			if a and not b and c and not d:
				wx.MessageBox(_("You Forgot add main function! Please add it"))
				return 1
			if a and b and not c and not d:
				if af.ishasimport("Src.GUI"):
					wx.MessageBox(_("Your code had some lost part Please Check it! wx.Frame not exist in code"))
					return 1
				else:
					Add2List()
					self.updat(event)
					return 1
			if a and b and c and d:
				Add2List()
				self.updat(event)
				return 1
			if not a and b and c and not d:
				wx.MessageBox(_("You forgot add [if __name__=='__main__'] to end of file. We add it!!"))
				mygnrt = Genrate2(self.thsfile)
				mygnrt.gnratLine(False, False, False, True, af.ishasframe())
				Add2List()
				self.updat(event)
				return 1
			if a and b and c and not d:
				if af.ishasimport("Src.GUI"):
					mygnrt = Genrate2(self.thsfile)
					#mygnrt.gnratLine(False, True, True, True, Framename=af.ishasframe())
					mygnrt.gnratLine(False,False,False,False, Framname=af.ishasframe())
					mygnrt.appendFile()
					lstcod = self.getMData.getHndid(self.thsdcod)
					newcod = int(self.thsdcod[0]) * 10000 + (int(self.thsdcod[1]) * 1000) + len(lstcod)  # +1
					newnom = int(self.thsdcod[0]) * 1000 + len(lstcod)  # +1
					data = [newcod, txt.replace('.py', ''), self.thsdcod, '-1', -1, newnom]
					self.setMDate.Table = 'handler'
					self.setMDate.Additem(" handlerid, prgname, prgdir, paramtr, public, prgno", data)
					wx.MessageBox(_("Program Successfull add to list"))
					#CheckDes(newcod)
					self.updat(event)
					return 1
				else:
					print('Src.GUI not found')
					return 1

			if not a and not b and not c and d:
			#elif af.ishaspanel():

				if af.ishaspanel() == 'MyPanel1':
					if cod[:2] == '55':
						newname = txt.replace('.py', '')
						dircode = self.thsdcod  # '5555'
						patfil = Src_aui  # self.thspath
						lstcod = self.getMData.getHndid(dircode)
						newcod = int(dircode[0]) * 10000 + len(lstcod)  # + 1
						newnom = int(dircode[0]) * 100 + len(lstcod)  # + 1
						print('Do 5555', patfil, newname, dircode, lstcod, newcod, newnom)
					else:
						dlg = MyDialog1(self)
						dlg.ShowModal()
						if dlg.filname:
							newname = dlg.filname
							dircode = self.getMData.GetDirCod2(dlg.pathfil)[0][0]
							lstcod = self.getMData.getHndid(dircode)
							patfil = dlg.pathfil
							newcod = int(dircode[1]) * 1000 + 10000 + len(lstcod) # + 1 * 10 + int(dircode[-1])
							newnom = int(dircode[1]) * 1000 + len(lstcod) #+ 1 * 10 + int(dircode[-1])
							#print(dircode,lstcod)
							mygnrt = Genrate(patfil.replace('..', MAP) + SLASH + newname + '.py')
							mygnrt.createFrm(self.thsfile)

					# elif dlg.box1.GetValue():
					# 	newname = txt.replace('.py','')
					# 	dircode = self.thsdcod #'5555'
					# 	patfil = self.thspath
					# 	lstcod = self.getMData.getHndid(dircode)
					# 	newcod = int(dircode[0]) * 10000 + len(lstcod) #+ 1
					# 	newnom = int(dircode[0]) * 100 + len(lstcod) #+ 1
					# 	#print('Do 5555',dlg.box1.GetValue())
						elif dlg.ensrf:   #Cancel MyDialog
							return 1
						else:
							newname = txt[0].upper()+txt[int(len(txt)/2)].upper()
							dircode = self.getMData.GetDirCod2(dlg.pathfil)[0][0]
							lstcod = self.getMData.getHndid(dircode)
							patfil = dlg.pathfil
							newcod = int(dircode[1]) * 1000 + 10000 + len(lstcod) #+ 1
							newnom = int(dircode[1]) * 1000 + len(lstcod) #+ 1
							#print('Do this 6666')
							mygnrt = Genrate(patfil.replace('..', MAP) + SLASH + newname + '.py')
							mygnrt.createFrm(self.thsfile)
						dlg.Destroy()
					#print(newcod,newname,dircode,newnom,patfil)
					data = [newcod, newname, dircode, '-1', -1, newnom]
					self.setMDate.Table = 'handler'
					self.setMDate.Additem(" handlerid, prgname, prgdir, paramtr, public, prgno", data)
					#CheckDes(newcod)
					self.updat(event)
			if not a and not b and not c and not d:
			#else:
				wx.MessageBox(_("Please move your file to API directory or use correct form! "))

		else:
			wx.MessageBox(_(u"You can only generate the unlisted program with end with this code '??'"))

		self.DVC1.DeleteAllItems()
		self.filllist()
		self.Refresh()
		#event.Skip()

	def gencod( self, event ):
	    event.Skip()

	def slctdir( self, event ):
		event.Skip()

	def public( self, event ):
		event.Skip()

	def dblst( self, event ):
		if wx.FindWindowByName(u'Database Develop') == None:
			import DCC1.DBDev2 as DB
			ifrm = wx.Frame(self, -1, style=wx.FRAME_FLOAT_ON_PARENT | wx.DEFAULT_FRAME_STYLE)
			pnl = DB.MyPanel1(ifrm, [self.GetParent(),self.dbfuse])
			ifrm.SetSize((555, 500))
			ifrm.SetTitle(u'Database use Program')
			ifrm.Show()
		else:
			wx.MessageBox(_("Double Program: Please Close Program Develop then Do this item"))

		event.Skip()

	def getData(self):
		D1 = self.fld1.GetValue()
		D2 = self.fld2.GetValue()
		D3 = self.fld3.GetValue()
		D4 = self.PrgDir1.GetPath()
		D5 = self.fld4.GetValue()
		D6 = self.fld6.GetValue()
		D7 = self.chk1.GetValue()
		return D1,D2,D3,D4,D5,D6,D7

	def Splt1OnIdle( self, event ):
		self.Splt1.SetSashPosition( 255 )
		self.Splt1.Unbind( wx.EVT_IDLE )


class MyDialog1 ( wx.Dialog ):

	def __init__( self, parent ):
		wx.Dialog.__init__ ( self, parent, id = wx.ID_ANY, title = wx.EmptyString, pos = wx.DefaultPosition, size = wx.Size( 365,165 ), style = wx.DEFAULT_DIALOG_STYLE )

		self.SetSizeHints( wx.DefaultSize, wx.DefaultSize )

		self.filname = ''
		self.pathfil = ''
		self.ensrf = False
		self.myMenu = MS.GetData(u'Menu2.db',u'')

		V1 = wx.BoxSizer( wx.VERTICAL )

		H1 = wx.BoxSizer( wx.HORIZONTAL )

		#self.box1 = wx.CheckBox(self, wx.ID_ANY, _(u"Create for Aui Pane"), wx.DefaultPosition, wx.DefaultSize, 0)
		#H1.Add(self.box1, 0, wx.ALL, 5)

		#V1.Add( H1, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )

		H2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl1 = wx.StaticText( self, wx.ID_ANY, _(u"name of file to create"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl1.Wrap( -1 )

		H2.Add( self.lbl1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.fld1 = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		H2.Add( self.fld1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		V1.Add( H2, 1, wx.EXPAND, 5 )

		H3 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self, wx.ID_ANY, _(u"choise path of file to create"), wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl2.Wrap( -1 )

		H3.Add( self.lbl2, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		chs1Choices = [ d[2] for d in self.myMenu.AllGuiDir(u" where Guidir.prgdir < '2000' and Guidir.prgdir > '1000' ") ]
		self.chs1 = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, chs1Choices, 0 )
		self.chs1.SetSelection( 0 )
		H3.Add( self.chs1, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		V1.Add( H3, 1, wx.EXPAND, 5 )

		H4 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancel"), wx.DefaultPosition, wx.DefaultSize, 0 )
		H4.Add( self.btn1, 0, wx.ALL, 5 )

		self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Ok"), wx.DefaultPosition, wx.DefaultSize, 0 )
		H4.Add( self.btn2, 0, wx.ALL, 5 )


		V1.Add( H4, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


		self.SetSizer( V1 )
		self.Layout()

		self.Centre( wx.BOTH )

		# Connect Events
		#self.box1.Bind( wx.EVT_CHECKBOX, self.foraui )
		self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
		self.btn2.Bind( wx.EVT_BUTTON, self.gtit )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	# def foraui( self, event ):
	# 	if self.box1.GetValue():
	# 		self.fld1.Disable()
	# 		self.chs1.Disable()
	# 	else:
	# 		self.fld1.Enable()
	# 		self.chs1.Enable()
	# 	event.Skip()

	def cncl( self, event ):
		self.ensrf = True
		self.Destroy()
		event.Skip()

	def gtit( self, event ):
		self.filname = self.fld1.GetValue()
		self.pathfil = self.chs1.GetStringSelection()
		#print(self.filname,self.pathfil)
		#print(self.myMenu.GetDirCod2(self.pathfil))
		self.ensrf = False
		self.Destroy()
		event.Skip()





# In the name of God
# -*- coding: utf-8 -*-
# Windows and Panels main Frame File
#! /usr/bin/env python

import wx
import wx.dataview
#import Database.wxmem as mem
import Database.wxsq as sq
#import Database.wxdb as db
#from khayyam import * 

    
class MyPanel1(wx.Panel):
    def __init__(self,parent,id,pos,size,style,ndata=[]):
        wx.Panel.__init__ ( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 142,396 ), style = wx.TAB_TRAVERSAL )

        self.parent = parent
        #self.ndata=ndata
        self.ndata = [u'Description',u'Data',u'Input',u'Account',u'Code',u'Date']
        
        self.SetLayoutDirection(1)
        
        bSizer2 = wx.BoxSizer( wx.VERTICAL )

        self.m_dataViewCtrl1 = wx.dataview.DataViewListCtrl( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.dataview.DV_HORIZ_RULES|wx.dataview.DV_MULTIPLE|wx.dataview.DV_ROW_LINES|wx.dataview.DV_VARIABLE_LINE_HEIGHT|wx.dataview.DV_VERT_RULES )

        self.DVCol = []
        for cloum in self.ndata:
            self.DVCol.append(self.m_dataViewCtrl1.AppendTextColumn(cloum,0))

        self.showitem()


        bSizer2.Add( self.m_dataViewCtrl1, 4, wx.ALL|wx.EXPAND, 5 )
        


        self.SetSizer( bSizer2 )
        self.Layout()

    def showitem(self):
        #now = JalaliDatetime.now().strftime('%N/%P/%K')
        now = wx.GetApp().GetConfig().Read("Date")
        #print(now)
        #for item in mylist:
        #            self.m_dataViewCtrl1.AppendItem(item[::-1])
                    #self.m_dataViewCtrl1.Bind(wx.dataview.EVT_DATAVIEW_ITEM_ACTIVATED,self.oncheng)
        


    def refresh(self):
        self.m_dataViewCtrl1.DeleteAllItems()
        self.m_dataViewCtrl1.Refresh()




# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc
import wx.grid

import numpy as np

###########################################################################
## Class MyPanel2
###########################################################################

class MyPanel2 ( wx.Panel ):

	def __init__( self, parent,testdata, leblslst, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,300 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
		wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

		self.conmatrix = np.array(testdata)
		rowc , colc = self.conmatrix.shape


		Vsz1 = wx.BoxSizer( wx.VERTICAL )


		self.grid1 = wx.grid.Grid( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, 0 )

		# Grid
		self.grid1.CreateGrid( rowc, colc )
		self.grid1.EnableEditing( True )
		self.grid1.EnableGridLines( True )
		self.grid1.EnableDragGridSize( False )
		self.grid1.SetMargins( 0, 0 )

		# Columns
		self.grid1.EnableDragColMove( False )
		self.grid1.EnableDragColSize( True )
		self.grid1.SetColLabelSize( 30 )
		for i in range(len(leblslst)):
			self.grid1.SetColLabelValue(i,leblslst[i])
		self.grid1.SetColLabelAlignment( wx.ALIGN_CENTER, wx.ALIGN_CENTER )

		# Rows
		self.grid1.EnableDragRowSize( True )
		self.grid1.SetRowLabelSize( 80 )
		for j in range(len(leblslst)):
			self.grid1.SetRowLabelValue( j, leblslst[j] )
		self.grid1.SetRowLabelAlignment( wx.ALIGN_CENTER, wx.ALIGN_CENTER )

		# Label Appearance

		# Cell Defaults
		self.grid1.SetDefaultCellAlignment( wx.ALIGN_LEFT, wx.ALIGN_TOP )
		Vsz1.Add( self.grid1, 0, wx.ALL|wx.EXPAND, 5 )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl1 = wx.StaticText( self, wx.ID_ANY, u"Per acc", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl1.Wrap( -1 )

		Hsz1.Add( self.lbl1, 1, wx.ALL, 5 )

		self.ClsLbls = []
		for a in leblslst:
			self.ClsLbls.append(   wx.StaticText( self, wx.ID_ANY, u"0.000", wx.DefaultPosition, wx.DefaultSize, 0 ) )
			self.ClsLbls[-1].Wrap( -1 )

			Hsz1.Add( self.ClsLbls[-1], 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz1, 1, wx.EXPAND, 5 )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl2 = wx.StaticText( self, wx.ID_ANY, u"F1 scores", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl2.Wrap( -1 )

		Hsz2.Add( self.lbl2, 1, wx.ALL, 5 )

		self.F1Lbls = []
		for a in leblslst:
			self.F1Lbls.append(  wx.StaticText( self, wx.ID_ANY, u"0.000", wx.DefaultPosition, wx.DefaultSize, 0 ) )
			self.F1Lbls[-1].Wrap( -1 )

			Hsz2.Add( self.F1Lbls[-1], 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz2, 1, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl3 = wx.StaticText( self, wx.ID_ANY, u"Total accuracy:", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl3.Wrap( -1 )

		Hsz3.Add( self.lbl3, 0, wx.ALL, 5 )

		self.Totlac = wx.StaticText( self, wx.ID_ANY, u"0.000", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.Totlac.Wrap( -1 )

		Hsz3.Add( self.Totlac, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz3, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )

		self.lbl4 = wx.StaticText( self, wx.ID_ANY, u"F1 average:", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.lbl4.Wrap( -1 )

		Hsz4.Add( self.lbl4, 0, wx.ALL, 5 )

		self.F1Avg = wx.StaticText( self, wx.ID_ANY, u"0.000", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.F1Avg.Wrap( -1 )

		Hsz4.Add( self.F1Avg, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz4, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )

		Hsz5 = wx.BoxSizer( wx.HORIZONTAL )

		self.btn = wx.Button( self, wx.ID_ANY, u"Close", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz5.Add( self.btn, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz5, 0, wx.ALIGN_RIGHT, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		self.FillGrid()

		# Connect Events
		self.btn.Bind( wx.EVT_BUTTON, self.closit )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def closit( self, event ):
		q = self.GetParent()
		q.Close()
		event.Skip()

	def FillGrid(self):
		i = j = 0
		for r in self.conmatrix.tolist():
			for c in r:
				self.grid1.SetCellValue(i,j,str(c))
				j += 1
			i += 1
			j = 0
		self.Comput_Accuracy_F1s()
		self.Comput_Total_Accuracy()


	def Item_Acc_F1(self, i):
		TP = self.conmatrix[i][i]
		FP = 0
		FN = 0
		TN = 0
		for m in range(len(self.conmatrix)):
			if m != i:
				FP += self.conmatrix[i][m]
		for m in range(len(self.conmatrix)):
			if m != i:
				FN += self.conmatrix[m][i]
		for m in range(len(self.conmatrix)):
			for n in range(len(self.conmatrix)):
				if m != i and n != i:
					TN += self.conmatrix[m][n]
		return (TP+TN)/(self.conmatrix.sum()),2*TP/(2*TP+FP+FN)

	def Comput_Accuracy_F1s(self):
		#for i in range(len(self.ClsLbls)):
		AvgF1 = 0
		for i in range(len(self.F1Lbls)):
			Acc,F1 =  self.Item_Acc_F1(i)
			AvgF1 += F1
			self.F1Lbls[i].SetLabel(str(round(F1,3)))
			self.ClsLbls[i].SetLabel(str(round(Acc,3)))
		AvgF1 = AvgF1 / len(self.F1Lbls)
		self.F1Avg.SetLabel(str(round(AvgF1,3)))
		pass


	def Comput_Total_Accuracy(self):
		TAcc = 0
		for i in range(len(self.conmatrix)):
			TAcc += self.conmatrix[i][i]
		TAcc = TAcc / self.conmatrix.sum()
		self.Totlac.SetLabel(str(round(TAcc,3)))






#In the name of GOD
#please put your code under here
#Supervised Learning
#Regresion Problem Normal Equesion
# -*- coding: utf-8 -*-
#!usr/bin/env python

from AI.Analiz import *

import numpy as np
from matplotlib import pyplot as plot
from mpl_toolkits.mplot3d import Axes3D

class CustFunction:
	def __init__(self):
		pass

	def GradientDescent(self, X, y, Theta, Alpha, NumItr):
		return 1


# In the name of God
# Main Program Start
#!/usr/bin/env python
# -*- coding: utf-8 -*-


from Allimp import *
import locale

from Config.Init import *
import GUI.window2 as window2
import GUI.Start as Strt


class mainApp(wx.App):

    def OnInit(self):
        self.locale = None
        wx.Locale.AddCatalogLookupPathPrefix(LOCALE_PATH)
        self.config = self.GetConfig()
        lang = self.config.Read("Language")
        langu_dic = LANGUAGE_LIST

        self.UpdateLanguage(langu_dic[int(lang)])
        self.SetAppName('Temp5')
        if self.config.Read('Splash') != '':
            splash = Strt.MySplashScreen(window2)
            splash.Show(True)
        else:
            frame = window2.MainWin()
            if self.config.Read('WinSize') != '(-1, -1)':
                SIZE = wx.Size(eval(self.config.Read(u'WinSize')))
            else:
                SIZE = (wx.GetDisplaySize()[0],wx.GetDisplaySize()[1]-30)
            frame.SetSize(SIZE)
            frame.SetPosition((0,0))
            #frame.EnableFullScreenView(True)
            frame.Show()
        return True

    def GetConfig(self):
        config = wx.FileConfig(appName='Temp5',localFilename=CONFIG_PATH+'option.ini',globalFilename=CONFIG_PATH+'system1.ini')
        return config

    def UpdateLanguage(self, lang):
        supportedLangs = {"English": wx.LANGUAGE_ENGLISH,
                          "Farsi": wx.LANGUAGE_FARSI,
                          "French": wx.LANGUAGE_FRENCH,
                          "German": wx.LANGUAGE_GERMAN,
                          "Spanish": wx.LANGUAGE_SPANISH,
                          "Turkish": wx.LANGUAGE_TURKISH,
                          }
        if self.locale:
            assert sys.getrefcount(self.locale) <= 2
            del self.locale
        if supportedLangs[lang]:
            self.locale = wx.Locale(supportedLangs[lang])
            if self.locale.IsOk():
                self.locale.AddCatalog("Temp5fa")
                # self.locale.AddCatalog("Temp5fr")
                self.locale.AddCatalog("Temp5de")
                # self.locale.AddCatalog("Temp5sp")
                # self.locale.AddCatalog("Temp5tr")
            else:
                self.locale = None
        else:
            wx.MessageBox("Language support not found please sending an email to us for update new language!")

def main(argv):
    #print(argv)
    if len(argv) > 0:
        if argv[0] == '-c':
            app = mainApp()
    else:
        app = mainApp(redirect=True)
        locale.setlocale(locale.LC_ALL, '')
    app.MainLoop()

if __name__ == '__main__':
    main(sys.argv[1:])


# -*- coding: utf-8 -*- 

###########################################################################
## Python code generated with wxFormBuilder (version Jun 17 2015)
## http://www.wxformbuilder.org/
##
## PLEASE DO "NOT" EDIT THIS FILE!
###########################################################################

import wx
#import wx.xrc
import re
try:
    from agw import hyperlink as hl
except ImportError: # if it's not there locally, try the wxPython lib.
    import wx.lib.agw.hyperlink as hl

###########################################################################
## Class MyPanel1
###########################################################################

class MyPanel1 ( wx.Panel ):

    def __init__( self, parent , txt='' , btn='Ok',id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.DefaultSize, style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
        """

        :type txt: object
        """
        wx.Panel.__init__ ( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,300 ), style = wx.TAB_TRAVERSAL )

        bSizer1 = wx.BoxSizer( wx.VERTICAL )

        bSizer2 = wx.BoxSizer( wx.VERTICAL )

        #print(type(txt))
        if isinstance(txt,str):
            url = re.search(r'(http?://\S+)', txt)
        else:
            url = None

        if url != None:
            url = url.group()
            txt = txt.replace(url,'')

        self.m_staticText1 = wx.StaticText( self, wx.ID_ANY, txt, wx.DefaultPosition, wx.DefaultSize, wx.ALIGN_CENTRE )
        self.m_staticText1.Wrap( -1 )

        bSizer2.Add( self.m_staticText1, 5, wx.ALL|wx.EXPAND, 5 )

        if url != None:

            self._hyper1 = hl.HyperLinkCtrl(self, wx.ID_ANY, url, wx.DefaultPosition, wx.DefaultSize,wx.ALIGN_CENTER, URL=url)
            bSizer2.Add(self._hyper1, 5, wx.ALL|wx.EXPAND, 5)



        bSizer1.Add( bSizer2, 1, wx.EXPAND, 5 )

        bSizer3 = wx.BoxSizer( wx.VERTICAL )

        self.m_button1 = wx.Button( self, wx.ID_ANY, btn, wx.DefaultPosition, wx.DefaultSize, 0 )
        bSizer3.Add( self.m_button1, 0, wx.ALIGN_CENTER|wx.ALL, 5 )


        bSizer1.Add( bSizer3, 0, wx.EXPAND, 5 )


        self.SetSizer( bSizer1 )
        self.Layout()

        # Connect Events
        self.m_button1.Bind( wx.EVT_BUTTON, self.onok )

    def __del__( self ):
        pass


    # Virtual event handlers, overide them in your derived class
    def onok( self, event ):
        q=self.GetParent()
        #print q
        q.Close()
        return -1





# In the name of God
# Configuration Program
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import sys
import os
import shutil

#### Main Application Path = MAP , Os name and Slash of OS
MAP = os.getcwd()
MyOsIs = os.name
if sys.platform == u'win32':
    SLASH = u'\\'
else:
    SLASH = u'/'

####  Some Utility function
def opj(path):
    """Convert paths to the platform-specific separator"""
    st = os.path.join(*tuple(path.split('/')))
    # HACK: on Linux, a leading / gets lost...
    if path.startswith('/'):
        st = '/' + st
    #print st
    return st

def _displayHook(obj):
    """
    Custom display hook to prevent Python stealing '_'.
    """
    if obj is not None:
        print(repr(obj))

#### Path of Program source for use inside of program
DATABASE_PATH = os.path.join(MAP,opj(u'Database')+SLASH)

AI_PATH       = os.path.join(MAP,opj(u'AI')+SLASH)
ML_PATH       = os.path.join(AI_PATH,opj(u'MLA')+SLASH)
DL_PATH       = os.path.join(AI_PATH,opj(u'DL')+SLASH)
DCC_PATH      = os.path.join(MAP,opj(u'DCC1')+SLASH)

GUI_PATH      = os.path.join(MAP,opj(u'GUI')+SLASH)
RES_PATH      = os.path.join(MAP,opj(u'Res')+SLASH)
SRC_PATH      = os.path.join(MAP,opj(u'Src')+SLASH)

ICONS_PATH    = os.path.join(RES_PATH,opj(u'Icons')+SLASH)
ICON16_PATH   = os.path.join(ICONS_PATH,opj(u'16x16')+SLASH)
ICON32_PATH   = os.path.join(ICONS_PATH,opj(u'32x32')+SLASH)
ICONS_MENU    = os.path.join(ICONS_PATH,opj(u'Menu')+SLASH)
ICONS_TOOL    = os.path.join(ICONS_PATH,opj(u'Toolbar')+SLASH)

PICS_PATH     = os.path.join(RES_PATH,opj(u'Pics')+SLASH)
IMAGE_PATH    = os.path.join(RES_PATH,opj(u'Images')+SLASH)
SPALSH_PATH   = os.path.join(RES_PATH,opj(u'Splash')+SLASH)

UTILITY_PATH  = os.path.join(MAP,opj(u'Utility')+SLASH)
CONFIG_PATH   = os.path.join(MAP,opj(u'Config')+SLASH)
LOGS_PATH     = os.path.join(MAP,opj(u'Logs')+SLASH)

LOCALE_PATH   = os.path.join(MAP,opj(u'Locale')+SLASH)

TEMPS_PATH    = os.path.join(MAP,opj(u'Temps')+SLASH)

#### Source pass for user

Src_api = os.path.join(SRC_PATH,opj(u'API')+SLASH)
Src_aui = os.path.join(SRC_PATH,opj(u'AUI')+SLASH)
Src_dbf = os.path.join(SRC_PATH,opj(u'DBF')+SLASH)
Src_gui = os.path.join(SRC_PATH,opj(u'GUI')+SLASH)
Src_mla = os.path.join(SRC_PATH,opj(u'MLA')+SLASH)
Src_mlp = os.path.join(SRC_PATH,opj(u'MLP')+SLASH)
Src_prg = os.path.join(SRC_PATH,opj(u'PRG')+SLASH)

Src_Dir = {'PRG':6111,'API':6122,'MLA':6133,'MLP':6144,'AUI':6155,'DBF':6166,'GUI':6177}
Src_Pth = {Src_prg:'PRG',Src_api:'API',Src_mla:'MLA',Src_mlp:'MLP',Src_aui:'AUI',Src_dbf:'DBF',Src_gui:'GUI'}

####  List of language to use in application
LANGUAGE_LIST = {1:"English",2:"Farsi",3:"French",4:"German",5:"Spanish",6:"Turkish"}
Database_type = {1:"sqlite",2:"mysql",3:"postgresql",4:"oracle",5:"sqlserver"}

#### other function to use in application
def thistxt(filename):
    with open(LOGS_PATH+filename,mode='r',encoding='utf-8') as f:
        lines = f.readlines()
    txt = ''
    for t in range(len(lines)):
            txt = txt + '\n' + lines[t]
    #print txt
    return txt

def fil2txt(filename):
    with open(filename, mode='r', encoding='utf-8') as f:
        lines = f.readlines()
    txt = ''
    for t in range(len(lines)):
        txt = txt + lines[t]
    return txt

def OpenListML():
    with open(CONFIG_PATH+u'MLmethod.ini', mode='r', encoding='utf-8') as f:
        lines = f.readlines()

    MLlst = {}
    MLAlg = {}
    for t in range(len(lines)):
        #print(lines[t])
        if ':' in lines[t]:
            #print(lines[t].split(':'))
            L1 = lines[t].split(':')
            l1 = L1[1].split(';')
            #print(L1,l1)
            MLlst[(int(l1[0]),int(l1[1].rstrip('\n')))] = L1[0].strip(' ')

        if ',' in lines[t]  and '    ' == lines[t][:4]:
            #print(lines[t].split(','))
            L1 = lines[t].split(',')
            l0 = L1[0].strip(' ')
            l1 = L1[1].split(';')
            MLAlg[(int(l1[0]),int(l1[1].rstrip('\n')))] = l0

    #print(MLlst,MLAlg)
    return MLlst,MLAlg

def CopyIcon(iconfile,thssrc=''):
    if thssrc == 'Menu':
        shutil.copy(iconfile, ICONS_MENU)
    elif thssrc == 'Toolbar':
        shutil.copy(iconfile, ICONS_TOOL)
    else:
        shutil.copy(iconfile, ICONS_PATH)


# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################

import wx
import wx.xrc
import wx.dataview

###########################################################################
## Class MyPanel1
###########################################################################

class MyPanel1 ( wx.Panel ):

	def __init__(self, parent, pnl=[], id=wx.ID_ANY, pos=wx.DefaultPosition, size=wx.Size(572, 420), style=wx.TAB_TRAVERSAL, name=wx.EmptyString):
		wx.Panel.__init__(self, parent, id=id, pos=pos, size=size, style=style, name=name)

		Vsz1 = wx.BoxSizer( wx.VERTICAL )

		self.pnl = pnl

		self.Titr1 = wx.StaticText( self, wx.ID_ANY, u"Define Models and Layers", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.Titr1.Wrap( -1 )

		Vsz1.Add( self.Titr1, 0, wx.ALL, 5 )

		self.P1 = wx.Panel( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz2 = wx.BoxSizer( wx.VERTICAL )

		self.TLC1 = wx.dataview.TreeListCtrl( self.P1, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.dataview.TL_DEFAULT_STYLE )
		self.TLC1.AppendColumn( u"Col1", wx.COL_WIDTH_DEFAULT, wx.ALIGN_LEFT, wx.COL_RESIZABLE )
		self.TLC1.AppendColumn( u"Col2", wx.COL_WIDTH_DEFAULT, wx.ALIGN_LEFT, wx.COL_RESIZABLE )

		Vsz2.Add( self.TLC1, 1, wx.EXPAND |wx.ALL, 5 )


		self.P1.SetSizer( Vsz2 )
		self.P1.Layout()
		Vsz2.Fit( self.P1 )
		Vsz1.Add( self.P1, 1, wx.EXPAND |wx.ALL, 5 )

		Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

		MChsChoices = [ u"Sequential", u"Functional" ]
		self.MChs = wx.Choice( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, MChsChoices, 0 )
		self.MChs.SetSelection( 1 )
		Hsz1.Add( self.MChs, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.txt1 = wx.StaticText( self, wx.ID_ANY, u"Models", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.txt1.Wrap( -1 )

		Hsz1.Add( self.txt1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lin1 = wx.StaticLine( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_HORIZONTAL|wx.LI_VERTICAL )
		Hsz1.Add( self.lin1, 0, wx.EXPAND |wx.ALL, 5 )

		self.fldin = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.fldin, 0, wx.ALL, 5 )

		self.txt2 = wx.StaticText( self, wx.ID_ANY, u"= Input ( ", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.txt2.Wrap( -1 )

		Hsz1.Add( self.txt2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.Input = wx.TextCtrl( self, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz1.Add( self.Input, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.txt3 = wx.StaticText( self, wx.ID_ANY, u")", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.txt3.Wrap( -1 )

		Hsz1.Add( self.txt3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz1.Add( Hsz1, 0, wx.EXPAND, 5 )

		self.P2 = wx.Panel( self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL )
		Vsz3 = wx.BoxSizer( wx.VERTICAL )

		Hsz2 = wx.BoxSizer( wx.HORIZONTAL )

		self.btnm1 = wx.Button( self.P2, wx.ID_ANY, u"Conv2D", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz2.Add( self.btnm1, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btnm2 = wx.Button( self.P2, wx.ID_ANY, u"Danse", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz2.Add( self.btnm2, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btnm3 = wx.Button( self.P2, wx.ID_ANY, u"Flotten", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz2.Add( self.btnm3, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btnm4 = wx.Button( self.P2, wx.ID_ANY, u"MaxPool2D", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz2.Add( self.btnm4, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btnm5 = wx.Button( self.P2, wx.ID_ANY, u"Dropout", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz2.Add( self.btnm5, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.lin2 = wx.StaticLine( self.P2, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.LI_VERTICAL )
		Hsz2.Add( self.lin2, 0, wx.EXPAND |wx.ALL, 5 )

		self.btnm6 = wx.Button( self.P2, wx.ID_ANY, u"VGG16", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz2.Add( self.btnm6, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btnm7 = wx.Button( self.P2, wx.ID_ANY, u"VGG19", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz2.Add( self.btnm7, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz2, 1, wx.EXPAND, 5 )

		Hsz3 = wx.BoxSizer( wx.HORIZONTAL )

		self.fldlay = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.fldlay, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.txt4 = wx.StaticText( self.P2, wx.ID_ANY, u"=", wx.DefaultPosition, wx.DefaultSize, 0 )
		self.txt4.Wrap( -1 )

		Hsz3.Add( self.txt4, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.layr = wx.TextCtrl( self.P2, wx.ID_ANY, wx.EmptyString, wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz3.Add( self.layr, 1, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )

		self.btnshw = wx.Button( self.P2, wx.ID_ANY, u"...", wx.DefaultPosition, wx.DefaultSize, wx.BU_EXACTFIT )
		Hsz3.Add( self.btnshw, 0, wx.ALL|wx.ALIGN_CENTER_VERTICAL, 5 )


		Vsz3.Add( Hsz3, 1, wx.EXPAND, 5 )


		self.P2.SetSizer( Vsz3 )
		self.P2.Layout()
		Vsz3.Fit( self.P2 )
		Vsz1.Add( self.P2, 1, wx.EXPAND |wx.ALL, 5 )

		Hsz4 = wx.BoxSizer( wx.HORIZONTAL )

		self.btnadd = wx.Button( self, wx.ID_ANY, u"Add", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.btnadd, 0, wx.ALL, 5 )

		self.btnedt = wx.Button( self, wx.ID_ANY, u"Edit", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.btnedt, 0, wx.ALL, 5 )

		self.btndel = wx.Button( self, wx.ID_ANY, u"Delete", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.btndel, 0, wx.ALL, 5 )

		self.btnsum = wx.Button( self, wx.ID_ANY, u"Summery", wx.DefaultPosition, wx.DefaultSize, 0 )
		Hsz4.Add( self.btnsum, 0, wx.ALL, 5 )


		Vsz1.Add( Hsz4, 0, wx.EXPAND, 5 )


		self.SetSizer( Vsz1 )
		self.Layout()

		# Connect Events
		self.MChs.Bind( wx.EVT_CHOICE, self.chngmodl )
		self.btnm1.Bind( wx.EVT_BUTTON, self.conv )
		self.btnm2.Bind( wx.EVT_BUTTON, self.dans )
		self.btnm3.Bind( wx.EVT_BUTTON, self.flot )
		self.btnm4.Bind( wx.EVT_BUTTON, self.mpool )
		self.btnm5.Bind( wx.EVT_BUTTON, self.drop )
		self.btnm6.Bind( wx.EVT_BUTTON, self.vgg16 )
		self.btnm7.Bind( wx.EVT_BUTTON, self.vgg19 )
		self.btnshw.Bind( wx.EVT_BUTTON, self.shwlyr )
		self.btnadd.Bind( wx.EVT_BUTTON, self.addlyr )
		self.btnedt.Bind( wx.EVT_BUTTON, self.edtlyr )
		self.btndel.Bind( wx.EVT_BUTTON, self.dellyr )
		self.btnsum.Bind( wx.EVT_BUTTON, self.sumodl )

	def __del__( self ):
		pass


	# Virtual event handlers, overide them in your derived class
	def chngmodl( self, event ):
		if self.MChs.GetSelection() == 0:
			self.fldin.Hide()
			self.fldlay.Hide()
		else:
			self.fldin.Show()
			self.fldlay.Show()
		self.Layout()
		self.Refresh()

		event.Skip()

	def conv( self, event ):
		event.Skip()

	def dans( self, event ):
		event.Skip()

	def flot( self, event ):
		event.Skip()

	def mpool( self, event ):
		event.Skip()

	def drop( self, event ):
		event.Skip()

	def vgg16( self, event ):
		event.Skip()

	def vgg19( self, event ):
		event.Skip()

	def shwlyr( self, event ):
		event.Skip()

	def addlyr( self, event ):
		event.Skip()

	def edtlyr( self, event ):
		event.Skip()

	def dellyr( self, event ):
		event.Skip()

	def sumodl( self, event ):
		event.Skip()



# In the name of God
# Main Program Start
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# import os
# import sys
# import glob
# import time
#
# import importlib
# import importlib.util
#
# import wx
# import wx.adv
# import wx.aui
# import wx.dataview
import wx

from Allimp import *
import platform

import GUI.MainMenu2 as MM
import GUI.MainTool as MT
import GUI.AuiPanel.PAui as PA
import GUI.BG2 as BG
import GUI.proman as pro

from Config.Init import *

_ = wx.GetTranslation

class MainWin(wx.Frame):
    def __init__(self):
        wx.Frame.__init__(self,None,title=u'',size=(-1,-1),name=u'main')

        # Get Program Config ===================

        self.config = wx.GetApp().GetConfig()

        wx.SystemOptions.SetOption("msw.remap", 2)

        label = self.config.Read(u'Winname')
        self.SetLabel(label)
        #self.SetBackgroundColour(wx.SystemSettings.GetColour(wx.SYS_COLOUR_BACKGROUND))
        self.newmenu = True

        if platform.system() == 'Windows':
            fntis = self.config.Read(u'Font').split(',')
            ifont = wx.Font(int(fntis[0]), int(fntis[1]), int(fntis[2]), int(fntis[3]), eval(fntis[4]), faceName=fntis[5])
            self.SetFont(ifont)

        self.SetSizeHints(wx.DefaultSize, wx.DefaultSize)
        self.m_mgr = wx.aui.AuiManager()
        self.m_mgr.SetManagedWindow(self)
        self.m_mgr.SetFlags(wx.aui.AUI_MGR_DEFAULT)

        # If like Back Gorund or Aui Center =============================
        if eval(self.config.Read('BGActive')):
            #self.BGrnd(self.config.Read('Background'))
            self.BGrnd(self.config.Read('BGActive.WinBG'))
        # If like use login =============================================
        if os.path.isfile(Src_aui+"login_pane.py"):
            import Src.AUI.login_pane as Lg
            dlg = wx.Dialog(self, -1, style=0)
            pnl = Lg.MyPanel1(dlg)
            dlg.SetSize((300,150))
            disply = wx.GetDisplaySize()
            dlg.SetPosition((disply[0] / 2 - 150, disply[1] / 2 - 75))
            dlg.ShowModal()
            if pnl.user == -1:
                exit()
            else:
                userid = pnl.user
            dlg.Destroy()
        else:
            userid = 1


        # Menu of Program Toolbar and Status ==========================
        if self.config.Read("Menu") == '1':
            self.menu = MM.AppMenu(userid)
            #self.menu.m.userid = userid
            if len(self.menu.GetMenus()) != 0:
                #self.SetMenuBar(menu)
                self.UpdateMenu(self.menu, self.menu.GetMenus())

            if self.config.Read('Toolbar') == '1':
                #self.Toolbar()
                self.ToolBar2()
                TBBG = self.config.Read("TBGColor").split(',')[1]
                self.tb.SetBackgroundColour(wx.SystemSettings.GetColour(int(TBBG)))
            elif self.config.Read('Toolbar') == '2':
                self.ToolPnl()

            self.MakeStatus()


        STBG = self.config.Read("SBGColor").split(',')[1]
        self.GetStatusBar().SetBackgroundColour(wx.SystemSettings.GetColour(int(STBG)))

        # All Panel Aui=======================
        self.APnls2()

        #self.BGrnd(BakGrnd)
        if userid == 1:
            self.Bind(wx.EVT_RIGHT_DOWN, self.domouse)
            self.Bind(wx.EVT_CONTEXT_MENU, self.setmenu)
        self.Bind(wx.EVT_CLOSE, self.OnClose)
        #self.Bind(wx.EVT_UPDATE_UI,self.Refreshwin)

        self.m_mgr.Update()
        self.Centre(wx.BOTH)

    def __del__(self):
        if platform.system() == 'windows':
            self.m_mgr.UnInit()


    def OnClose(self, event):
        if 'timer' in dir(self):
            if self.timer.IsRunning():
                self.timer.Stop()
                del self.timer
        self.Destroy()

    def Notify(self):
        t = time.localtime(time.time())
        st = time.strftime("%I:%M:%S", t)
        self.SetStatusText(st, self.stnbr)

    def MakeStatus(self):
        lststat = eval(self.config.Read('Status'))
        i = 1
        Wthlst = [-1]

        statusBar = self.CreateStatusBar(len(lststat) + 1,
                                         wx.STB_ELLIPSIZE_END | wx.STB_ELLIPSIZE_MIDDLE | wx.STB_SHOW_TIPS | wx.STB_SIZEGRIP,
                                         wx.ID_ANY)

        # statusBar.SetBackgroundColour(wx.SystemSettings.GetColour(wx.SYS_COLOUR_BTNSHADOW))
        for st in lststat:
            if st == 'time':
                # Timer in status ============================================
                self.timer = wx.PyTimer(self.Notify)
                self.timer.Start(1000)
                Wthlst.append(90)
            elif st == 'date':
                t = time.localtime(time.time())
                self.SetStatusText(time.strftime("%d-%b-%Y", t), i)
                Wthlst.append(90)
            elif st == 'path':
                ipath = os.getcwd() #  self.config.Read('AppPath')
                #print(ipath)
                self.SetStatusText(ipath,i)
                Wthlst.append(-1)
            #else:
            #    self.SetStatusText(st, i)
            #    Wthlst.append(-1)
            i += 1
        self.SetStatusBar(statusBar)

        self.stnbr = len(Wthlst) - 1
        self.SetStatusWidths(Wthlst)
        self.SetStatusBarPane(0)
        if 'time' in lststat:
            self.Notify()


    def domouse(self, event):
        self.setmenu(event)

    def setmenu(self, event):
        self.MnuDic = {1: [_(u'Menu Change'), 9999], 2: [_(u'Toolbar Change'), 9998], 3: [_(u'Panes Change'), 9997], 4: [u'', 0],
                       5: [_(u'Databases...'), 9996], 6: [_(u'Programs...'), 9995], 7: [_(u'Add Tools...'), 9994], 8: [u'', 0],
                       9: [_(u'MLA Design...'), 9993], 10: [u'', 0], 11: [_(u'Settings...'), 9992]}
        self.m1 = wx.Menu()

        self.itms = []
        i = 0
        for itm in self.MnuDic:
            self.Bind(wx.EVT_MENU, self.OnPopupOne, id=itm)
            if self.MnuDic[itm][0] == u'':
                self.m1.AppendSeparator()
            else:
                # self.itms.append( wx.MenuItem(self.m1, wx.ID_ANY, MnuDic[itm][0], wx.EmptyString) )
                self.m1.Append(itm, self.MnuDic[itm][0])
                #self.Bind(wx.EVT_MENU, self.OnPopupOne, id=MnuDic[itm][1])
                i = i + 1

        self.PopupMenu(self.m1)
        self.m1.Destroy()

    def OnPopupOne(self, event):
        pmid = event.GetId()
        a = pro.DoProgram2(self.MnuDic[pmid][1], '')
        win1 = wx.Frame(self, -1)
        a.main(win1)

    def OnMenu(self, event):
        self.mid = event.GetId()
        a = pro.DoProgram2(self.mid, '')
        win1 = wx.Frame(self, -1)
        a.main(win1)

    def OnTool(self, event):
        self.tid = event.GetId()
        a = pro.DoProgram2(self.tid, '')
        win1 = wx.Frame(self, -1)
        a.main(win1)

    def ToolBar2(self):
        #self.tb = self.CreateToolBar(wx.TB_HORIZONTAL | wx.NO_BORDER | wx.TB_FLAT | wx.TB_TEXT)
        self.tb = MT.MyToolbar(self,wx.TB_HORIZONTAL | wx.NO_BORDER | wx.TB_FLAT|wx.TB_TEXT)
        self.tb.data = MT.ToolData()
        #print(self.tb.data.ToolBarList())
        tsize = (24, 24)  # <<<=====use Config
        self.tb.SetToolBitmapSize(tsize)
        tbdata = self.tb.data.ToolBarList()
        #print(tbdata)
        self.tb.CreatTool(tbdata)
        self.SetToolBar(self.tb)
        if len(tbdata) > 0:
            self.Bind(wx.EVT_TOOL_RANGE, self.OnTool, id=tbdata[1][0][0], id2=tbdata[len(tbdata)][-1][0])


    def ToolPnl(self):
        self.tool = []
        MTBL = MT.ToolData()
        MLT = MTBL.ToolBarList()
        i = 0
        for T in MLT:

            MTB = MT.MyAuiToolbar(self)
            MyTL = MTB.data

            self.tool.append( MTB.CreatTool(MLT[T]) )
            self.tool[i].SetToolBitmapSize(wx.Size(24, 24)) #<<<=== use Config
            self.tool[i].Realize()
            self.m_mgr.AddPane(self.tool[i], wx.aui.AuiPaneInfo().Name("tb"+str(i)).Caption("Toolbar").
                           ToolbarPane().Top().LeftDockable(True).RightDockable(False))
            self.Bind(wx.EVT_TOOL_RANGE, self.OnTool, id=self.tool[i].mytb[0].GetId(), id2=self.tool[i].mytb[-1].GetId())
            i += 1


    def APnls2(self):
        StartPane = eval(self.config.Read('Panes'))
        self.Pnls = []
        ML = PA.MyLstPnl2()

        for pnl in ML.lstpnl:
            #if pnl[1]+'.py' in MLA.GetAuiPnl():
            if pnl[6] in ML.PrP.keys():
                ii = importlib.import_module('Src.AUI.' +  ML.PrP[pnl[6]].replace('.py',''))
                mp = ii.MyPanel1(self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.TAB_TRAVERSAL)
                self.Pnls.append(mp)
                PInfo = ML.GetAuiInfo(pnl[1])
                self.m_mgr.AddPane(mp, PInfo)
                if pnl[1] in StartPane:
                    self.m_mgr.GetPane(pnl[1]).Show()
                else:
                    self.m_mgr.GetPane(pnl[1]).Hide()

    def BGrnd(self,BGF):
        self.bmpwin = BG.BGPanel(self,BGF)
        self.m_mgr.AddPane( self.bmpwin, wx.aui.AuiPaneInfo() .CaptionVisible( False ) .Center() .CloseButton( False ).Dock().Resizable().FloatingSize( wx.Size( 800,600 )) )


    def NewMenu(self):
        self.newmenu = True
        self.barMenu = wx.MenuBar()
        self.SetMenuBar(self.barMenu)
        return self.barMenu

    def UpdateMenu(self,imenu,menu):
        self.SetMenuBar(imenu)

        frstitm = menu[0][0].GetMenuItems()
        lastitm = menu[-1][0].GetMenuItems()
        if len(frstitm) != 0:
            h = frstitm[0].GetId()
            #h1 = lastitm[-1].GetId()
            #print(h,h1)
            #self.Bind(wx.EVT_MENU_RANGE, self.OnMenu, id=h1, id2=h.GetId())
            self.Bind(wx.EVT_MENU_RANGE, self.OnMenu, id=101, id2=9999)

    def NewToolBar(self):
        self.toolbar = MT.MyToolbar()
        self.SetToolBar()

    def Refreshwin(self):
        self.Refresh()
        self.Update()
        #self.UpdateWindowUI(wx.UPDATE_UI_FROMIDLE)


# In the name of God
#! /usr/bin/env python
# -*- coding: utf-8 -*-
# Run program here

from Allimp import importlib

import Database.MenuSet2 as MS
#import importlib
#import importlib.util
from Config.Init import *


class Mymenu(object):
    def __init__(self):
        self.MySql = MS.GetData(u'Menu2.db', u'')
        self.ToSql = MS.SetData(u'', u'',u'')

    def program(self, itemid):
        self.handler = self.MySql.MyProg(itemid=itemid)
        return self.handler[0][1]

    def toogram(self, itolid):
        self.handler = self.MySql.MyTogr(itolid)
        return self.handler[0][1]

    def menudir(self, itemid):
        self.directory = self.MySql.MnuDir2(itemid)
        if self.directory != [] :
            return self.directory[0][0]
        #else:
        #    return ''

    def submndir(self, itemsub):
        self.directory = self.MySql.SubDir2(itemsub)
        return self.directory[0][0]

    def tooldir(self, itolid):
        self.directory = self.MySql.TolDir2(itolid)
        return self.directory[0][0]

    def Dohndlr(self):
        return self.MySql.DoHdnl()

    def Runhdlr(self, handlerid):
        return self.MySql.RunHdnl(handlerid)[0]

    #def Revitm(self):
    #    return self.MySql.RevItem()


def DoProgram2(itm,hndlr):
    M = Mymenu()

    if itm > 1000 and itm < 9000:
        P = M.program(itm)
        d = M.menudir(itm)
        if not d:
            d = M.submndir(itm)

    elif itm < 1000 and itm > 100:
        P = M.toogram(itm)
        d = M.tooldir(itm)

    elif itm > 9000:
        P = M.program(itm)
        d = 'GUI.Main'

    else:
        P = ''
        d = ''
        if hndlr != '':
            d,P = M.Runhdlr(hndlr)

    a = d+'.'+P
    #print(a)
    try:
        i = importlib.import_module(a)
    except ImportError as error:
        print(error)
        i = -1
    #print(dir(i))
    return i




# -*- coding: utf-8 -*-

###########################################################################
## Python code generated with wxFormBuilder (version Oct 26 2018)
## http://www.wxformbuilder.org/
##
## PLEASE DO *NOT* EDIT THIS FILE!
###########################################################################


import wx
import wx.aui as wxaui
import wx.adv
import wx.propgrid as pg
import os
import sys
import platform
import Database.MenuSet2 as MS
import GUI.BG2
from Config.Init import *
import Res.Allicons as icon

_ = wx.GetTranslation

#################################################################################
##  Size Property Class
##
#################################################################################
class SizeProperty(pg.PGProperty):
    """ Demonstrates a property with few children.
    """
    def __init__(self, label, name = pg.PG_LABEL, value=wx.Size(0, 0)):
        pg.PGProperty.__init__(self, label, name)

        value = self._ConvertValue(value)

        self.AddPrivateChild( pg.IntProperty("X", value=value.x) )
        self.AddPrivateChild( pg.IntProperty("Y", value=value.y) )

        self.m_value = value
        #print(self.m_value)

    def GetClassName(self):
        return self.__class__.__name__

    def DoGetEditorClass(self):
        return pg.PropertyGridInterface.GetEditorByName("TextCtrl")

    def RefreshChildren(self):
        size = self.m_value
        self.Item(0).SetValue( size.x )
        self.Item(1).SetValue( size.y )

    def _ConvertValue(self, value):
        """ Utility convert arbitrary value to a real wx.Size.
        """
        import collections
        if isinstance(value, collections.abc.Sequence) or hasattr(value, '__getitem__'):
            value = wx.Size(*value)
        return value

    def ChildChanged(self, thisValue, childIndex, childValue):
        size = self._ConvertValue(self.m_value)
        if childIndex == 0:
            size.x = childValue
        elif childIndex == 1:
            size.y = childValue
        else:
            raise AssertionError

        return size

###########################################################################
# Check Property class
#
###########################################################################
#class checkProperty(pg.PGCheckBoxEditor)


###########################################################################
## Class MyPanel1
###########################################################################


class MyPanel1 ( wx.Panel ):

    def __init__( self, parent, id = wx.ID_ANY, pos = wx.DefaultPosition, size = wx.Size( 500,500 ), style = wx.TAB_TRAVERSAL, name = wx.EmptyString ):
        wx.Panel.__init__ ( self, parent, id = id, pos = pos, size = size, style = style, name = name )

        #self.panel = panel = wx.Panel(self, wx.ID_ANY)
        #print(panel.GetSize())
        self.MyMenu = MS.GetData(u'Menu2.db', u'')

        LAuiP = [ l[0] for l in self.MyMenu.ListPanes() ]

        Statu = [u'path',u'date',u'time']
        #print(LAuiP)

        language = [LANGUAGE_LIST[lan] for lan in LANGUAGE_LIST]
        DBtype   = [Database_type[dbt] for dbt in Database_type ]
        lan = [lan for lan in LANGUAGE_LIST ]
        DBt = [Dtyp for Dtyp in Database_type]

        Vsz1 = wx.BoxSizer( wx.VERTICAL )

        self.pgm = pg.PropertyGridManager(self, wx.ID_ANY, wx.DefaultPosition, wx.DefaultSize, wx.propgrid.PG_DESCRIPTION|wx.propgrid.PG_SPLITTER_AUTO_CENTER|wx.propgrid.PG_TOOLBAR|wx.TAB_TRAVERSAL)
        #self.pgm.SetExtraStyle( wx.propgrid.PG_EX_MODE_BUTTONS )
        self.pgm.ExtraStyle |= pg.PG_EX_HELP_AS_TOOLTIPS

        self.pgm.Bind(pg.EVT_PG_CHANGED, self.OnPropGridChange)
        self.pgm.Bind(pg.EVT_PG_PAGE_CHANGED, self.OnPropGridPageChange)
        self.pgm.Bind(pg.EVT_PG_SELECTED, self.OnPropGridSelect)
        self.pgm.Bind(pg.EVT_PG_RIGHT_CLICK, self.OnPropGridRightClick)

        self.config = wx.GetApp().GetConfig()


        PansLst = eval(self.config.Read("Panes"))
        StatLst = eval(self.config.Read("Status"))
        self.ifont = self.config.Read(u'Font')
        TBGname,self.TBGCol = self.config.Read(u'TBGColor').split(',')
        SBGname,self.SBGCol = self.config.Read(u'SBGColor').split(',')
        Winsize = wx.Size(eval(self.config.Read(u'WinSize')))
        #Winsize = (int(self.config.Read(u'WinSize').split(',')[0]),int(self.config.Read(u'WinSize').split(',')[1]))
        #print(Winsize)

        mw = wx.GetTopLevelWindows()

        if platform.system() == 'Windows':
            fntis = self.config.Read(u'Font').split(',')
            ifont = wx.Font(int(fntis[0]),int(fntis[1]),int(fntis[2]),int(fntis[3]),eval(fntis[4]),faceName=fntis[5])
        else:
            ifont = wx.Font()


        conflst = {u"General properties":[(u'Enum',_(u"Language"), u"Language",u"",language,lan,int(self.config.Read("Language")) ),
                                          (u"Image",_(u"Splash"),u"Splash",_(u"Use this file for Splash"),self.config.Read('Splash') ),
                                          (u"Enum",_(u"Database type"),u"DBtype",u"",DBtype,DBt,int(self.config.Read('DBtype')) )
                                          ],
                   u"Main Window properties":[(u'String',_(u'Label of Window'),u'Winname',_(u'Show label of Main window'),self.config.Read(u'Winname')),
                                              (u'Size',_(u'Window Size'),u'WinSize',_(u'Set Main Window Size start'),Winsize),
                                              (u'Bool',_(u"Back Ground Active"),u"BGActive",u"UseCheckbox",eval(self.config.Read('BGActive'))),
                                              #(u"Image",u"Background",u"Background",u"If Active BackGround Use this file",self.config.Read('Background')),
                                              #(u"Enum",u"Type of Menu",u"Menu",u"",[u'Normal',u'Flat'],[1,2],int(self.config.Read("Menu"))),
                                              (u"Enum",_(u"Type of Toolbar"),u"Toolbar",u"",[u'Normal',u'Aui'],[1,2],int(self.config.Read("Toolbar"))),
                                              (u"SysColor",_(u"Toolbar Background"),u"TBGColor",_(u"Toolbar Background colour set"),self.TBGCol),
                                              (u"MChoice",_(u"Start Panes"),u"Panes",_(u"Start this panes in Main Window"),LAuiP,PansLst),
                                              (u"Font",_(u"Main Window Font"),u"Font",u"",ifont),
                                              (u"MChoice",_(u"Show in Status "),u"Status",u"",Statu,StatLst),
                                              (u"SysColor",_(u"Status Background Color"),u"SBGColor",_(u"Status background colour set"),self.SBGCol)]
        }

        self.P1 = self.pgm.AddPage( u"General Properties Page", wx.Bitmap(icon.setting_tools.GetBitmap()) );

        Items1 = []
        for con in conflst:
            Items1.append(self.P1.Append( pg.PropertyCategory(con, con)))
            for itm in conflst[con]:
                if itm[0] == u"Enum":
                    Items1.append(self.P1.Append( pg.EnumProperty(itm[1],itm[2],itm[4],itm[5],itm[6]) ))
                    Items1[-1].SetHelpString(itm[3])
                elif itm[0] == u"Image":
                    Items1.append(self.P1.Append( pg.ImageFileProperty(itm[1],itm[2],value=itm[4]) ))
                    Items1[-1].SetHelpString(itm[3])
                elif itm[0] == u"Bool":
                    Items1.append(self.P1.Append( pg.BoolProperty(itm[1],itm[2],value=itm[4]) ))
                    #Items1[-1].SetHelpString(itm[3])
                    self.pgm.SetPropertyAttribute(itm[2],itm[3],True )
                elif itm[0] == u"MChoice":
                    Items1.append(self.P1.Append( pg.MultiChoiceProperty(itm[1],itm[2],choices=itm[4],value=itm[5]) ) )
                    Items1[-1].SetHelpString(itm[3])
                elif itm[0] == u"Font":
                    Items1.append(self.P1.Append( pg.FontProperty(itm[1],itm[2],ifont) ) )
                    Items1[-1].SetHelpString(itm[3])
                elif itm[0] == u'SysColor':
                    Items1.append(self.P1.Append( pg.SystemColourProperty(itm[1],itm[2])))
                    Items1[-1].SetHelpString(itm[3])
                    Items1[-1].SetValue(wx.SystemSettings.GetColour(int(itm[4])))
                    #print(Items1[-1])
                elif itm[0] == u'String':
                    Items1.append(self.P1.Append( pg.StringProperty(itm[1],itm[2],itm[4])))
                    Items1[-1].SetHelpString(itm[3])
                elif itm[0] == u'Size':
                    Items1.append(self.P1.Append( SizeProperty(itm[1],itm[2],value=wx.Size(itm[4]))))
                else:
                    print("something error")

        #print(self.config.Read(u'DBtype.UPH'))
        if self.config.Read(u'DBtype.Usr') != '':
            #self.P1.AppendIn(u'DBtype', pg.StringProperty('User: Password: Host:', 'UPH', self.config.Read(u'DBtype.UPH')))
            self.P1.AppendIn(u'DBtype',pg.StringProperty('User: ', 'Usr', self.config.Read(u'DBtype.Usr')))
            pwd = self.P1.AppendIn(u'DBtype',pg.StringProperty('Password: ', 'Pwd', self.config.Read(u'DBtype.Pwd')))
            pwd.SetAttribute('Password', True)
            self.P1.AppendIn(u'DBtype',pg.StringProperty('Host: ', 'Hst', self.config.Read(u'DBtype.Hst')))
            #self.P1.AppendIn(u'DBtype',pg.StringProperty('Port: ', 'UPH', self.config.Read(u'DBtype.UPH')))

        if self.config.Read(u'BGActive.WinBG') != '':
            self.P1.AppendIn(u'BGActive', pg.ImageFileProperty("BackGround","WinBG",self.config.Read('BGActive.WinBG') ))





        MAP = os.getcwd()
        dirlst = {u'Main Directory and Path':[(u"Application Path",'AppPath',u"The Path of application and work program",MAP),
                                              (u"Database Path",u'DBPath',u'',MAP+u'\\Src\\DBF'),
                                              (u"API source path",u'APIPath',u"The path of application program interface ",MAP+u'\\Src\\API'),
                                              (u"Program of Menu Bar Path",u"PRGPath",u"",MAP+u"\\Src\\PRG"),
                                              (u"GUI Panel Path",u'GUIPath',u'',MAP+u'\\Src\\GUI')
                                              ],
                  u"Resouce and images":[(u"Fonts Path",u'Fonts',u'',MAP+u'\\Res\\Fonts'),
                                         (u"Icon Menu Path",u'MenuPath',u'',MAP+u'\\Res\\Icons\\Menu'),
                                         (u"Icon Toolbar Path",u'ToolPath',u'',MAP+u'\\Res\\Icons\\Toolbar'),
                                         (u"Image Path",u'ImgPath',u'',MAP+u'\\Res\\Images'),
                                         (u"Picture Path",u'PicPath',u'',MAP+u'\\Res\\Pics'),
                                         (u"Splash Path", u'SplshPath', u'', MAP + u'\\Res\\Splash')
                                         ],

                  u"Other Path":[(u"Temp Path",u'TmpPath',u'',MAP+u'\\Temps'),
                                 (u"Log Path",u'LogPath',u'',MAP+u'\\Logs'),
                                 (u"Utility Path",u'UtilPath',u'',MAP+u'\\Utility'),
                                 (u"Config Path",u'ConPath',u'',MAP+u'\\Config'),
                                 ],
                  u"Machin Learning Source":[(u"Machine Learning Algorithm",u'MLAPath',u'',MAP+u'\\Src\\MLA'),
                                             (u"Machine Learning Panel",u'MLPPath',u'',MAP+u'\\Src\\MLP')]
                  }
        self.Itms = []


        self.P2 = self.pgm.AddPage( u"Directory and Path Page", wx.Bitmap(icon.folders.GetBitmap()) );
        for itm in dirlst:
            #print(itm)
            self.Itms.append(self.P2.Append(pg.PropertyCategory(itm,itm)))
            for tm in dirlst[itm]:
                self.Itms.append(self.P2.Append(pg.DirProperty(tm[0],tm[1],value=tm[3])))
                self.P2.SetPropertyHelpString(self.Itms[-1], tm[2])


        Vsz1.Add( self.pgm, 1, wx.ALL|wx.EXPAND, 5 )

        Hsz1 = wx.BoxSizer( wx.HORIZONTAL )

        self.btn1 = wx.Button( self, wx.ID_ANY, _(u"Cancle"), wx.DefaultPosition, wx.DefaultSize, 0 )
        Hsz1.Add( self.btn1, 0, wx.ALL, 5 )

        self.btn2 = wx.Button( self, wx.ID_ANY, _(u"Apply"), wx.DefaultPosition, wx.DefaultSize, 0 )
        Hsz1.Add( self.btn2, 0, wx.ALL, 5 )


        Vsz1.Add( Hsz1, 0, wx.ALIGN_CENTER_HORIZONTAL, 5 )


        self.SetSizer( Vsz1 )
        self.Layout()

        # Connect Events
        self.btn1.Bind( wx.EVT_BUTTON, self.cncl )
        self.btn2.Bind( wx.EVT_BUTTON, self.aply )

    def __del__( self ):
        pass


    # Virtual event handlers, overide them in your derived class
    def cncl( self, event ):
        q = self.GetParent()
        q.Close()


    def aply( self, event ):
        d = self.pgm.GetPropertyValues(inc_attributes=True)
        v = self.pgm.GetPropertyValues(as_strings=True)
        #print(d)
        e = self.pgm.GetPropertyValues()
        #print(e)
        self.config = wx.GetApp().GetConfig()
        if e['DBtype'] != 1 and e['DBtype.Usr'] == '' and e['DBtype.Pwd'] == '':
            wx.MessageBox(_(" info of User Password and Host forgot. Please Enter information "))
            return 1
        if not e['BGActive']:
            self.config.Write('BGActive.WinBG', '' )
        for itm in e:
            if itm == 'TBGColor':
                #print(e[itm])
                self.config.Write(itm,v[u'TBGColor']+','+str(self.TBGCol))
            elif itm == 'SBGColor':
                self.config.Write(itm,v[u'SBGColor']+','+str(self.SBGCol))
            elif itm == 'Font':
                self.config.Write('Font', self.ifont)
            elif itm == 'DBtype':
                if e[itm] == 1:
                    self.config.Write(itm, str(e[itm]))
                    self.config.Write('DBtype.Usr', '')
                    self.config.Write('DBtype.Pwd', '')
                    self.config.Write('DBtype.Hst', '')
                else:
                    self.config.Write(itm, str(e[itm]))

            #elif itm == 'DBtype.UPH':
            #    print(itm, str(e[itm]))
            else:
                self.config.Write(itm,str(e[itm]))

        self.config.Flush()
        wx.MessageBox(_("Config file changed. You must Start application again to see the change"))
        q = self.GetParent()
        q.Close()


    def OnPropGridChange(self, event):
        p = event.GetProperty()
        v = self.pgm.GetPropertyValues(as_strings=True)
        #print('change',p.GetValue(),p.GetName(),p.GetLabel(),p.GetDisplayedString())
        if p.GetName() == 'BGActive':
            if p.GetValue():
                #print(p.GetValue())
                if not self.P1.GetPropertyByName('BGActive.WinBG'):
                    self.P1.AppendIn("BGActive", pg.ImageFileProperty("BackGround","WinBG",self.config.Read('WinBG')))
                else:
                    self.P1.GetPropertyByName("BGActive.WinBG").Hide(False, pg.PG_DONT_RECURSE)
                    bmpwin = wx.GetTopLevelWindows()
                    if 'bmpwin' in dir(bmpwin[0]):
                        bmpwin[0].bmpwin.Show()

            else:
                if self.P1.GetPropertyByName("BGActive.WinBG"):
                    self.P1.GetPropertyByName("BGActive.WinBG").Hide(True, pg.PG_DONT_RECURSE)
                    #print("Delete background")
                    bmpwin = wx.GetTopLevelWindows()
                    if 'bmpwin' in dir(bmpwin[0]):
                        bmpwin[0].bmpwin.Hide()

        #if p.GetName() == 'Background':
        if p.GetName() == 'BGActive.WinBG':
            if p.GetValue() != '':
                bmpwin = wx.GetTopLevelWindows()
                if 'bmpwin' in dir(bmpwin[0]):
                    bmpwin[0].bmpwin.BGfile = p.GetValue()
                    bmpwin[0].bmpwin.ChangeBackGround()
                else:
                    wx.MessageBox(_("Please Apply your chnage if you like see Background"))

        if p.GetName() == u'Font':
            #print(v[u'Font'])
            wfont = p.GetValue()
            minwin = wx.GetTopLevelWindows()

            f1 = wfont.GetPointSize()
            f2 = wfont.GetFamily()
            f3 = wfont.GetStyle()
            f4 = wfont.GetWeight()
            f5 = wfont.GetUnderlined()
            f6 = wfont.GetFaceName()
            #print(f1,f2,f3,f4,f5,f6)
            self.ifont = str(f1)+','+str(f2)+','+str(f3)+','+str(f4)+','+str(f5)+','+f6
            #print(minwin[0],wfont)
            minwin[0].SetFont(wfont)
            minwin[0].SetOwnFont(wfont)
            minwin[0].Refresh()
            minwin[0].m_mgr.Update()

        if p.GetName() == u'TBGColor':
            #print(v[u'TBGColor'])
            wcolor = p.GetValue()
            self.TBGCol = wcolor.m_type
            minwin = wx.GetTopLevelWindows()
            #print(minwin[0].GetToolBar())
            minwin[0].GetToolBar().SetBackgroundColour(wx.SystemSettings.GetColour(wcolor.m_type))
            minwin[0].Refresh()

        if p.GetName() == u'SBGColor':
            #print(v[u'SBGColor'])
            wcolor = p.GetValue()
            #print(wcolor.m_type)
            self.SBGCol = wcolor.m_type
            minwin = wx.GetTopLevelWindows()
            #print(minwin[0].GetStatusBar().GetFieldsCount())
            minwin[0].GetStatusBar().SetBackgroundColour(wx.SystemSettings.GetColour(wcolor.m_type))
            minwin[0].Refresh()

        if p.GetName() == u'DBtype':
            dbtyp = p.GetValue()
            #print(dbtyp, type(dbtyp))
            if dbtyp in [2,3,4]: #>= 2 or dbtyp <= 5:
                #if self.P1.GetPropertyByName('DBtype.UPH'):
                    #print('i found it')
                    #self.P1.GetPropertyByName('DBtype.UPH').Hide(False, pg.PG_DONT_RECURSE)
                if not self.P1.GetPropertyByName('DBtype.Usr'):
                    self.P1.AppendIn(u'DBtype', pg.StringProperty('User: ', 'Usr', ''))
                else:
                    self.P1.GetPropertyByName('DBtype.Usr').Hide(False, pg.PG_DONT_RECURSE)

                if not self.P1.GetPropertyByName('DBtype.Pwd'):
                    pwd = self.P1.AppendIn(u'DBtype', pg.StringProperty('Password: ', 'Pwd', ''))
                    pwd.SetAttribute('Password', True)
                else:
                    pwd = self.P1.GetPropertyByName('DBtype.Pwd').Hide(False, pg.PG_DONT_RECURSE)


                if not self.P1.GetPropertyByName('DBtype.Hst'):
                    self.P1.AppendIn(u'DBtype', pg.StringProperty('Host: ', 'Hst', ''))
                else:
                    self.P1.GetPropertyByName('DBtype.Hst').Hide(False, pg.PG_DONT_RECURSE)

            else:
                #if self.P1.GetPropertyByName('DBtype.UPH'):
                    #self.P1.GetPropertyByName('DBtype.UPH').Hide(True, pg.PG_DONT_RECURSE)
                if self.P1.GetPropertyByName('DBtype.Usr'):
                    self.P1.GetPropertyByName('DBtype.Usr').Hide(True, pg.PG_DONT_RECURSE)
                if self.P1.GetPropertyByName('DBtype.Pwd'):
                    self.P1.GetPropertyByName('DBtype.Pwd').Hide(True, pg.PG_DONT_RECURSE)
                if self.P1.GetPropertyByName('DBtype.Hst'):
                    self.P1.GetPropertyByName('DBtype.Hst').Hide(True, pg.PG_DONT_RECURSE)
            #    self.P1.HideProperty(u'DBtype.UPH', True, pg.PG_DONT_RECURSE)

        self.P1.RefreshGrid()


    def OnPropGridSelect(self, event):
        p = event.GetProperty()
        #print('select',dir(p))

    def OnPropGridRightClick(self, event):
        p = event.GetProperty()
        #print('Right',p)

    def OnPropGridPageChange(self, event):
        index = self.pgm.GetSelectedPage()
        #print('Page N',index)



# In the name of God
############ Description ############
##  This is a Sample Demo File
##  Only four line you can use for
##  Description
##
############### End ###############
# -*- coding: utf-8 -*-
# !usr/bin/env python

import wx
import GUI.API.SamPnl as SPnl
from Config.Init import *


class Demoframe(wx.Frame):
	def __init__(self, parent):
		wx.Frame.__init__(self, parent, style=wx.FRAME_FLOAT_ON_PARENT | wx.DEFAULT_FRAME_STYLE)
		self.parent = parent
		#you can add code here before create panel

		self.panel = SPnl.MyPanel1(self)

	def closeit(self):
		self.Close(True)


def size():
	return (-1, -1)


def main(panel=None):
	parent = panel.GetParent()
	frame = Demoframe(parent)
	frame.SetTitle(u'Demo')
	frame.SetSize((500, 300))
	frame.Show()


if __name__ == '__main__':
	main()



# In the name of God
# -*- coding: utf-8 -*-
# Windows and Panels main Frame File
# ! /usr/bin/env python

import wx
import wx.lib.gizmos as gizmos  # Formerly wx.gizmos in Classic
import time
from datetime import datetime

class MyPanel1(wx.Panel):
	def __init__(self, parent, id, pos, size, style):
		wx.Panel.__init__(self, parent, id=wx.ID_ANY, pos=wx.DefaultPosition, size=wx.Size(-1, -1),
		                  style=wx.TAB_TRAVERSAL)

		self.parent = parent


		#VSiz = wx.BoxSizer(wx.VERTICAL)
		# You must write your source here
		led = gizmos.LEDNumberCtrl(self, -1, (0, 0), (250, 50),
		                           gizmos.LED_ALIGN_CENTER)  # | gizmos.LED_DRAW_FADED)
		led.SetForegroundColour('black')
		led.SetBackgroundColour('white')

		datetime.strftime()

		#VSiz.Add(led, 1,wx.ALL,5)
		self.clock = led
		self.OnTimer(None)

		self.timer = wx.Timer(self)
		self.timer.Start(1000)
		self.Bind(wx.EVT_TIMER, self.OnTimer)

		#self.SetSizer(VSiz)
		self.Layout()

	def OnTimer(self, evt):
		t = time.localtime(time.time())
		st = time.strftime("%H:%M:%S", t)
		self.clock.SetValue(st)


#In the name of God
# -*- coding: utf-8 -*-
#!usr/bin/env python

import wx
import Src.API.Pnl0 as Pnl0
from  Config.Init import *

class telframe(wx.Frame):
    def __init__(self,parent):
        wx.Frame.__init__(self,parent,style=wx.FRAME_FLOAT_ON_PARENT|wx.DEFAULT_FRAME_STYLE)
        self.parent=parent

        txt = thistxt('disit.txt')
        btn = u'ok'
               
        self.panel = Pnl0.MyPanel1(self,txt,btn)

        
    def closeit(self):
        self.Close(True)

def size():
    return (-1,-1)

def main(panel=None ):
    locale = wx.Locale(wx.LANGUAGE_ENGLISH)
    
    parent =  panel.GetParent()
    
    frame = telframe(parent )
    frame.SetTitle(u'Note')
    frame.SetSize((300,160))
    frame.Show()
    

    

if __name__ == '__main__':
    #app = wx.App(False) 
    main()
    #app.MainLoop()
    
